Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(165)

Unified Diff: test/mozilla/testcfg.py

Issue 1367933002: [test] Fetch mozilla test data from SVN. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/mozilla/testcfg.py
diff --git a/test/mozilla/testcfg.py b/test/mozilla/testcfg.py
index c6bfc1fda8546bc917f8f9851e845d18ab89f6d7..5316105ca53989f48185f3bfc9cb16b48122638e 100644
--- a/test/mozilla/testcfg.py
+++ b/test/mozilla/testcfg.py
@@ -34,11 +34,12 @@ import tarfile
from testrunner.local import testsuite
from testrunner.objects import testcase
+SVN_SERVER = (
+ "svn://svn.chromium.org/chrome/trunk/deps/third_party/mozilla-tests")
+MOZILLA_VERSION = "51236"
-MOZILLA_VERSION = "2010-06-29"
-
-EXCLUDED = ["CVS"]
+EXCLUDED = ["CVS", ".svn"]
FRAMEWORK = """
@@ -147,9 +148,9 @@ class MozillaTestSuite(testsuite.TestSuite):
os.chdir(old_cwd)
return
- # No cached copy. Check out via CVS, and pack as .tar.gz for later use.
- command = ("cvs -d :pserver:anonymous@cvs-mirror.mozilla.org:/cvsroot"
- " co -D %s mozilla/js/tests" % MOZILLA_VERSION)
+ # No cached copy. Check out via SVN, and pack as .tar.gz for later use.
+ command = ("svn co -r %s %s mozilla/js/tests" %
+ (MOZILLA_VERSION, SVN_SERVER))
code = subprocess.call(command, shell=True)
if code != 0:
os.chdir(old_cwd)
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698